{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../desktop.nix
  ];

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "atlas";
  networking.hostId = "8425e349";
  networking.networkmanager.enable = true;

  nix.package = pkgs.nixFlakes;
  nix.extraOptions = ''
    experimental-features = nix-command flakes
  '';

  users.defaultUserShell = pkgs.zsh;

  system.stateVersion = "22.11";

  modules = {
    desktop = {
      apps = {
        qbittorrent.enable = true;
        thunderbird.enable = true;
      };
      browsers = {
        firefox.enable = true;
      };
      media.graphics = {
        raster.enable = true;
        vector.enable = true;
      };
      office.libreoffice.enable = true;
    };
    dev = {
      node.enable = true;
    };
    editors = {
      neovim.enable = true;
      vscode.enable = true;
    };
    security = {
      gpg.enable = true;
      pass.enable = true;
    };
    shell = {
      git.enable = true;
      zsh.enable = true;
    };
  };
}
