{ config, lib, pkgs, ... }:

{
  time.timeZone = "Europe/London";

  i18n.defaultLocale = "en_GB.UTF-8";
  i18n.extraLocaleSettings = {
    LC_ADDRESS = "en_GB.UTF-8";
    LC_IDENTIFICATION = "en_GB.UTF-8";
    LC_MEASUREMENT = "en_GB.UTF-8";
    LC_MONETARY = "en_GB.UTF-8";
    LC_NAME = "en_GB.UTF-8";
    LC_NUMERIC = "en_GB.UTF-8";
    LC_PAPER = "en_GB.UTF-8";
    LC_TELEPHONE = "en_GB.UTF-8";
    LC_TIME = "en_GB.UTF-8";
  };

  console.keyMap = "uk";

  services.printing.enable = true;
  services.openssh = {
    enable = true;
    settings = {
      KbdInteractiveAuthentication = false;
      PasswordAuthentication = false;
      PermitRootLogin = "no";
    };
    startWhenNeeded = true;
  };

  sound.enable = true;
  hardware.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };

  environment.systemPackages = with pkgs; [
    git
    neovim
  ];

  system.autoUpgrade = {
    enable = true;
    flake = "git+ssh://git@git.vimium.com/jordan/nix-config.git";
    randomizedDelaySec = "10min";
  };

  nix = {
    settings = {
      connect-timeout = 5;
      log-lines = 25;
      min-free = 128000000;
      max-free = 1000000000;
      fallback = true;
      auto-optimise-store = true;
      substituters = [
        "http://odyssey.mesh.vimium.net"
        "https://cache.nixos.org"
      ];
      trusted-public-keys = [
        "odyssey.mesh.vimium.net:ZhQhjscPWjoN4rlZwoMELznEiBnZ9O26iyGA27ibilQ="
      ];
    };
    gc = {
      automatic = true;
      dates = "weekly";
      options = "-d --delete-older-than 7d";
    };
  };

  modules.desktop.gnome.enable = true;
  modules.networking.tailscale.enable = true;
}
