{ config, lib, pkgs, inputs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../desktop.nix
  ];

  boot = {
    loader.grub = {
      enable = true;
      device = "/dev/sda";
      zfsSupport = true;
    };
  };

  networking = {
    hostName = "helios";
    hostId = "47d23505";
    networkmanager.enable = true;
  };

  nix.package = pkgs.nixFlakes;
  nix.extraOptions = ''
    experimental-features = nix-command flakes
  '';

  users.defaultUserShell = pkgs.zsh;

  system.stateVersion = "22.11";

  modules = {
    desktop = {
      apps.qbittorrent.enable = true;
      browsers = {
        firefox.enable = true;
      };
    };
    dev = {
      node.enable = true;
    };
    editors = {
      neovim.enable = true;
    };
    security = {
      gpg.enable = true;
      pass.enable = true;
    };
    services = {
      borgmatic = {
        enable = true;
        directories = [
          "/home/jordan/Documents"
        ];
        repoPath = "ssh://b9cjl9hq@b9cjl9hq.repo.borgbase.com/./repo";
      };
    };
    shell = {
      git.enable = true;
      zsh.enable = true;
    };
  };
}
