{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../desktop.nix
  ];

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  networking = {
    hostName = "hypnos";
    hostId = "cf791898";
    networkmanager.enable = true;
  };

  nix = {
    package = pkgs.nixFlakes;
    extraOptions = ''
      experimental-features = nix-command flakes
    '';
  };

  modules = {
    desktop = {
      browsers = {
        firefox.enable = true;
      };
    };
    dev = {
      node.enable = true;
    };
    editors = {
      neovim.enable = true;
    };
    networking = {
      wireless.enable = true;
    };
    security = {
      gpg.enable = true;
      pass.enable = true;
    };
    shell = {
      git.enable = true;
      zsh.enable = true;
    };
  };

  system.stateVersion = "22.11";
}
