{ config, lib, pkgs, ... }:

let cfg = config.modules.desktop.gnome;
in {
  options.modules.desktop.gnome = {
    enable = lib.mkOption {
      default = false;
      example = true;
    };
  };

  config = lib.mkIf cfg.enable {
    services.xserver = {
      enable = true;
      displayManager.gdm.enable = true;
      desktopManager.gnome.enable = true;
    };

    services.flatpak.enable = true;

    programs.dconf.enable = true;
    dconf.settings = {
      "org/gnome/shell" = {
        disable-user-extensions = false;
        enabled-extensions = [
          # "another-window-session-manager@gmail.com"
          "blur-my-shell@aunetx"
          "burn-my-windows@schneegans.github.com"
          # "desktop-cube@schneegans.github.com"
          # "desktop-zoom@colin.kinlo.ch"
          "espresso@coadmunkee.github.com"
          # "flypie@schneegans.github.com"
          # "forge@jmmaranan.com"
          "hue-lights@chlumskyvaclav@gmail.com"
          "just-perfection-desktop@just-perfection"
          # "pano@elhan.io"
          # "paperwm@hedning:matrix.org"
          # "search-light@icedman.github.com"
          "space-bar@luchrioh"
          # "smart-auto-move@khimaros.com"
          # "systemd-manager@hardpixel.eu"
          # "tailscale-status@maxgallup.github.com"
          # "tiling-assistant@leleat-on-github"
          "Vitals@CoreCoding.com"
          # "wsmatrix@martin.zurowietz.de"
        ];
        favorite-apps = [
          "firefox.desktop"
          "org.gnome.Nautilus.desktop"
        ];
      };
      "org/gnome/shell/extensions/another-window-session-manager" = {
        enable-autorestore-sessions = true;
      };
      "org/gnome/shell/extensions/blur-my-shell/panel" = {
        static-blur = true;
      };
      "org/gnome/shell/extensions/blur-my-shell/applications" = {
        blur = false;
      };
      "org/gnome/shell/extensions/burn-my-windows" = {
        fire-close-effect = false;
        glide-open-effect = true;
        glide-close-effect = true;
      };
      "org/gnome/shell/extensions/desktop-zoom" = {
        mag-factor-delta = 0.07;
      };
      "org/gnome/shell/extensions/espresso" = {
        enable-fullscreen = true;
        show-indicator = true;
        show-notifications = false;
        inhibit-apps = [
          "com.obsproject.Studio.desktop"
        ];
      };
      "org/gnome/shell/extensions/paperwm" = {
        use-default-background = true;
      };
      "org/gnome/shell/extensions/forge" = {
        window-gap-size = 8;
        window-gap-hidden-on-single = false;
      };
      "org/gnome/shell/extensions/just-perfection" = {
        activities-button = false;
        window-demands-attention-focus = true;
        workspace-wrap-around = true;
      };
      "org/gnome/shell/extensions/space-bar/behavior" = {
        enable-activate-workspace-shortcuts = true;
        show-empty-workspaces = true;
        smart-workspace-names = false;
      };
      "org/gnome/shell/extensions/tiling-assistant" = {
        screen-top-gap = 8;
        screen-right-gap = 8;
        screen-bottom-gap = 8;
        screen-left-gap = 8;
        window-gap = 8;
      };
      "org/gnome/desktop/background" = {
        picture-uri = "file://${pkgs.gnome.gnome-backgrounds}/share/backgrounds/gnome/adwaita-l.jpg";
        picture-uri-dark = "file://${pkgs.gnome.gnome-backgrounds}/share/backgrounds/gnome/adwaita-d.jpg";
      };
      "org/gtk/settings/file-chooser" = {
        show-hidden = true;
        sort-directories-first = true;
      };
      "org/gtk/gtk4/settings/file-chooser" = {
        show-hidden = true;
        sort-directories-first = true;
      };
      "org/gnome/settings-daemon/plugins/media-keys" = {
        volume-up = [
          "<Shift>F12"
          "XF86AudioRaiseVolume"
        ];
        volume-down = [
          "<Shift>F11"
          "XF86AudioLowerVolume"
        ];
      };
      "org/gnome/gnome-session" = {
        auto-save-session = true;
      };
      "org/gnome/gnome-system-monitor" = {
        show-dependencies = true;
      };
      "org/gnome/Console" = {
        font-scale = 1.4;
      };
      "org/gnome/mutter" = {
        center-new-windows = true;
        edge-tiling = true;
        experimental-features = [ "scale-monitor-framebuffer" ];
      };
      "org/gnome/desktop/interface" = {
        color-scheme = "prefer-dark";
        enable-hot-corners = false;
        monospace-font-name = "Ubuntu Mono 11";
      };
      "org/gnome/desktop/wm/keybindings" = {
        switch-group = [ "<Super>grave" ];
        switch-group-backward = [ "<Shift><Super>grave" ];
      };
      "io/github/celluloid-player/celluloid" = {
        draggable-video-area-enable = true;
      };
    };

    fonts.packages = with pkgs; [
      noto-fonts
      ubuntu_font_family
    ];

    user.packages = with pkgs; [
      celluloid
      fragments
      mission-center
    ];

    environment.systemPackages = with pkgs; [
      bind
      bmon
      fd
      ffmpeg
      gnome.gnome-boxes
      gnomeExtensions.another-window-session-manager
      # gnomeExtensions.bifocals
      gnomeExtensions.blur-my-shell
      gnomeExtensions.browser-tabs
      gnomeExtensions.burn-my-windows
      gnomeExtensions.desktop-cube
      gnomeExtensions.desktop-zoom
      gnomeExtensions.espresso
      gnome44Extensions."flypie@schneegans.github.com"
      # gnomeExtensions.forge
      # gnomeExtensions.gsnap
      gnomeExtensions.hue-lights
      gnomeExtensions.just-perfection
      # gnomeExtensions.mutter-primary-gpu
      gnomeExtensions.pano
      gnomeExtensions.paperwm
      # gnomeExtensions.pip-on-top
      gnomeExtensions.rounded-window-corners
      gnomeExtensions.search-light
      gnomeExtensions.smart-auto-move
      gnomeExtensions.space-bar
      gnomeExtensions.systemd-manager
      gnomeExtensions.tailscale-status
      gnomeExtensions.tiling-assistant
      # gnomeExtensions.todotxt
      gnomeExtensions.vitals
      # gnomeExtensions.window-is-ready-remover
      # gnomeExtensions.worksets
      # gnomeExtensions.workspace-matrix
      iotop
      ripgrep
      rsync
      tcpdump
      tokei
      tree
      wl-clipboard
    ] ++ (if config.virtualisation.podman.enable then [
      pods
    ] else []);

    home.services.gpg-agent.pinentryFlavor = "gnome3";
  };
}
